==> ejc-jlincome-api-3.0.0-20240927.045143-255-sources.jar: com/ejianc/business/jlincome/income/vo/ProjectBoardVO.java <==
package com.ejianc.business.jlincome.income.vo;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 项目看板
 * 
 * @author generator
 * 
 */
public class ProjectBoardVO extends BaseVO {
    private static final long serialVersionUID = 1L;


    private Integer projectNum; //项目总数
    private Integer bidProjectNum; //中标项目
    private BigDecimal incomeContractMny; //收入合同
    private BigDecimal invoiceMny; //开票金额
    private BigDecimal settleAMny; //对甲结算金额
    private BigDecimal receiveMny; //收款金额
    private BigDecimal payContractMny; //支出合同金额
    private BigDecimal collectMny; //收票金额
    private BigDecimal settleMny; //结算金额
    private BigDecimal payMny; //付款金额


    public Integer getProjectNum() {
        return projectNum;
    }

    public void setProjectNum(Integer projectNum) {
        this.projectNum = projectNum;
    }

    public Integer getBidProjectNum() {
        return bidProjectNum;
    }

    public void setBidProjectNum(Integer bidProjectNum) {
        this.bidProjectNum = bidProjectNum;
    }

    public BigDecimal getIncomeContractMny() {
        return incomeContractMny;
    }

    public void setIncomeContractMny(BigDecimal incomeContractMny) {
        this.incomeContractMny = incomeContractMny;
    }

    public BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    public void setInvoiceMny(BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }

    public BigDecimal getSettleAMny() {
        return settleAMny;
    }

    public void setSettleAMny(BigDecimal settleAMny) {
        this.settleAMny = settleAMny;
    }

    public BigDecimal getReceiveMny() {
        return receiveMny;
    }

    public void setReceiveMny(BigDecimal receiveMny) {
        this.receiveMny = receiveMny;
    }

    public BigDecimal getPayContractMny() {
        return payContractMny;
    }

    public void setPayContractMny(BigDecimal payContractMny) {
        this.payContractMny = payContractMny;
    }

    public BigDecimal getCollectMny() {
        return collectMny;
    }

    public void setCollectMny(BigDecimal collectMny) {
        this.collectMny = collectMny;
    }

    public BigDecimal getSettleMny() {
        return settleMny;
    }

    public void setSettleMny(BigDecimal settleMny) {
        this.settleMny = settleMny;
    }

    public BigDecimal getPayMny() {
        return payMny;
    }

    public void setPayMny(BigDecimal payMny) {
        this.payMny = payMny;
    }
}

==> ejc-jlincome-api-3.0.0-20241105.091410-320-sources.jar: com/ejianc/business/jlincome/income/vo/ProjectBoardVO.java <==
package com.ejianc.business.jlincome.income.vo;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 项目看板
 * 
 * @author generator
 * 
 */
public class ProjectBoardVO extends BaseVO {
    private static final long serialVersionUID = 1L;


    private Integer projectNum = 0; //项目总数
    private Integer bidProjectNum = 0; //中标项目
    private BigDecimal incomeContractMny = BigDecimal.ZERO; //收入合同
    private BigDecimal invoiceMny = BigDecimal.ZERO; //开票金额
    private BigDecimal settleAMny = BigDecimal.ZERO; //对甲结算金额
    private BigDecimal receiveMny = BigDecimal.ZERO; //收款金额
    private BigDecimal payContractMny = BigDecimal.ZERO; //支出合同金额
    private BigDecimal collectMny = BigDecimal.ZERO; //收票金额
    private BigDecimal settleMny = BigDecimal.ZERO; //结算金额
    private BigDecimal payMny = BigDecimal.ZERO; //付款金额


    public Integer getProjectNum() {
        return projectNum;
    }

    public void setProjectNum(Integer projectNum) {
        this.projectNum = projectNum;
    }

    public Integer getBidProjectNum() {
        return bidProjectNum;
    }

    public void setBidProjectNum(Integer bidProjectNum) {
        this.bidProjectNum = bidProjectNum;
    }

    public BigDecimal getIncomeContractMny() {
        return incomeContractMny;
    }

    public void setIncomeContractMny(BigDecimal incomeContractMny) {
        this.incomeContractMny = incomeContractMny;
    }

    public BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    public void setInvoiceMny(BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }

    public BigDecimal getSettleAMny() {
        return settleAMny;
    }

    public void setSettleAMny(BigDecimal settleAMny) {
        this.settleAMny = settleAMny;
    }

    public BigDecimal getReceiveMny() {
        return receiveMny;
    }

    public void setReceiveMny(BigDecimal receiveMny) {
        this.receiveMny = receiveMny;
    }

    public BigDecimal getPayContractMny() {
        return payContractMny;
    }

    public void setPayContractMny(BigDecimal payContractMny) {
        this.payContractMny = payContractMny;
    }

    public BigDecimal getCollectMny() {
        return collectMny;
    }

    public void setCollectMny(BigDecimal collectMny) {
        this.collectMny = collectMny;
    }

    public BigDecimal getSettleMny() {
        return settleMny;
    }

    public void setSettleMny(BigDecimal settleMny) {
        this.settleMny = settleMny;
    }

    public BigDecimal getPayMny() {
        return payMny;
    }

    public void setPayMny(BigDecimal payMny) {
        this.payMny = payMny;
    }
}
